# l10n documentation

```{include} ../README.md
:start-after: "# l10n"
:end-before: "## l10n in 30 seconds"
```

## Documentation

+ [TL;DR](./quickstart.md) is a guide for impatient that in 30 seconds shows you how to use l10n.
+ [Getting Started](./intro.md) walks you through the process of creating and translating your first Python project.
+ [Advanced usage](./advanced.md) goes deeper into details and going beyond translating simple messages.
+ [Beyond l10n](./more.md) links some helpful tools and resources to find your way around of translating things.
+ [What we stripped away](./removed.md) tells the secret of l10n's simplicity.

Source code is available on GitHub: [github.com/orsinium-labs/l10n](https://github.com/orsinium-labs/l10n)

## Pages

```{eval-rst}

.. toctree::
    :maxdepth: 1

    quickstart
    intro
    advanced
    more
    removed
    api
```
